@@ -315,6 +315,10 @@ void create_tables()
             "ナビゲーションの「状態別チケット」または「チケット検索」からチケット情報の一覧を表示させることができます。チケット情報の一覧から、詳細情報を見たいチケットのIDか件名のリンクをクリックすることでチケット詳細ページに移動します。チケット詳細ページでは、チケットの最新情報、チケットの履歴を見ることができます。また、チケットに返信することもできます。  \n"
             "**チケットに対して返信を行なうには？\n"
             "ナビゲーションメニューの「状態別チケット」または「チケット検索」からチケット情報の一覧を表示させることができます。チケット情報の一覧から、詳細情報を見たいチケットのIDか件名のリンクをクリックすることでチケット詳細ページに移動します。チケット詳細ページの下にチケット返信のフォームがありますので、必要な項目を入力して返信ボタンを押してください。  \n"
+            "**他チケットにリンクを貼るには？\n"
+            "複数行テキスト項目の値には、他のチケットの詳細ページへのリンクを貼ることができます。#1 のように、書くと、チケットIDが 1 のチケットへのリンクになります。  \n"
+            "**ソースコードなどを貼るには？\n"
+            "複数行テキスト項目の値には、整形済ブロック用の記法が用意されています。ソースコードなどを貼る場合に、インデントを崩さずに表示することができます。行頭が >| から始まる行から、行頭が |< から始まる行までを整形済ブロックとして表示します。  \n"
             "', current_timestamp);", COLUMN_TYPE_END);
     exec_query(
             "insert into wiki(id, name, content, registerdate) values (NULL, 'adminhelp', '"
