@@ -9,6 +9,7 @@
 #include "util.h"
 #include "wiki.h"
 #include "hook.h"
+#include "simple_string.h"
 
 typedef enum _NAVI {
     NAVI_OTHER,
@@ -106,7 +107,7 @@ void output_header(Project* project, char* title, char* script_name, NaviType na
       "<ul id='menu'>\n");
     o("<li><a href='%s' title=\"ホームへ移動します\">ホーム</a></li>\n", project->home_url);
     o("<li><a %s href='%s' title=\"トップページへ移動します\">トップ</a></li>\n", navi == NAVI_TOP ? "class=\"current\"" : "", cgiScriptName);
-    o("<li><a %s href='%s/list' title=\"状態別のチケット一覧を参照します\">状態別チケット</a></li>\n", navi == NAVI_LIST ? "class=\"current\"" : "", cgiScriptName);
+    o("<li><a %s href='%s/list' title=\"状態別のチケット一覧を参照します\">状態別チケット一覧</a></li>\n", navi == NAVI_LIST ? "class=\"current\"" : "", cgiScriptName);
     o("<li><a %s href='%s/register' title=\"新規にチケットを登録します\">チケット登録</a></li>\n", navi == NAVI_REGISTER ? "class=\"current\"" : "", cgiScriptName);
     o("<li><a %s href='%s/search' title=\"チケットを検索します\">チケット検索</a></li>\n", navi == NAVI_SEARCH ? "class=\"current\"" : "", cgiScriptName);
     o("<li><a %s href='%s/statistics' title=\"統計情報を表示します\">統計情報</a></li>\n", navi == NAVI_STATISTICS ? "class=\"current\"" : "", cgiScriptName);
@@ -158,13 +159,12 @@ void output_navigater(SearchResult* result, char* query_string)
         o("<a href=\"%s/search?p=%d&amp;%s\">&gt;&gt;</a>\n", cgiScriptName, result->page + 1, query_string);
     o("</div>\n");
 }
-char* format_query_string_without_page(char* buffer)
+String* format_query_string_without_page(String* buffer)
 {
     char **array, **arrayStep;
     if (cgiFormEntries(&array) != cgiFormSuccess) {
-        return "";
+        return buffer;
     }
-    strcpy(buffer, "");
     arrayStep = array;
     while (*arrayStep) {
         if (strcmp(*arrayStep, "p") != 0) {
@@ -174,10 +174,10 @@ char* format_query_string_without_page(char* buffer)
             strcpy(name, *arrayStep);
             cgiFormStringNoNewlines(name, value, DEFAULT_LENGTH);
             url_encode(value, encodedvalue, DEFAULT_LENGTH);
-            strcat(buffer, name);
-            strcat(buffer, "=");
-            strcat(buffer, encodedvalue);
-            strcat(buffer, "&amp;");
+            string_append(buffer, name);
+            string_append(buffer, "=");
+            string_append(buffer, encodedvalue);
+            string_append(buffer, "&amp;");
         }
         arrayStep++;
     }
@@ -185,13 +185,12 @@ char* format_query_string_without_page(char* buffer)
 
     return buffer;
 }
-char* format_query_string_without_sort_and_page(char* buffer)
+String* format_query_string_without_sort_and_page(String* buffer)
 {
     char **array, **arrayStep;
     if (cgiFormEntries(&array) != cgiFormSuccess) {
-        return "";
+        return buffer;
     }
-    strcpy(buffer, "");
     arrayStep = array;
     while (*arrayStep) {
         if (strcmp(*arrayStep, "rsort") != 0 &&
@@ -203,10 +202,10 @@ char* format_query_string_without_sort_and_page(char* buffer)
             strcpy(name, *arrayStep);
             cgiFormStringNoNewlines(name, value, DEFAULT_LENGTH);
             url_encode(value, encodedvalue, DEFAULT_LENGTH);
-            strcat(buffer, name);
-            strcat(buffer, "=");
-            strcat(buffer, encodedvalue);
-            strcat(buffer, "&amp;");
+            string_append(buffer, name);
+            string_append(buffer, "=");
+            string_append(buffer, encodedvalue);
+            string_append(buffer, "&amp;");
         }
         arrayStep++;
     }
@@ -235,23 +234,24 @@ void output_ticket_table_header(List* element_types)
 {
     Iterator* it;
     char* reverse = strstr(cgiQueryString, "rsort=");
-    char query_string_buffer[DEFAULT_LENGTH];
-    char* query_string = format_query_string_without_sort_and_page(query_string_buffer);
+    String* query_string_a = string_new(0);
+    query_string_a = format_query_string_without_sort_and_page(query_string_a);
 
     o(      "\t<tr>\n");
-    o(      "\t\t<th class=\"id\"><a href=\"%s/search?%ssort=-1&amp;%s#result\" title=\"押す度に昇順、降順で並べ替えを行ないます。\">ID</a></th>\n", cgiScriptName, reverse ? "" : "r", query_string);
+    o(      "\t\t<th class=\"id\"><a href=\"%s/search?%ssort=-1&amp;%s#result\" title=\"押す度に昇順、降順で並べ替えを行ないます。\">ID</a></th>\n", cgiScriptName, reverse ? "" : "r", string_rawstr(query_string_a));
     foreach (it, element_types) {
         ElementType* et = it->element;
         o("\t\t<th class=\"field%d\">\n", et->id);
-        o("\t\t\t<a href=\"%s/search?%ssort=%d&amp;%s#result\" title=\"押す度に昇順、降順で並べ替えを行ないます。\">", cgiScriptName, reverse ? "" : "r", et->id, query_string);
+        o("\t\t\t<a href=\"%s/search?%ssort=%d&amp;%s#result\" title=\"押す度に昇順、降順で並べ替えを行ないます。\">", cgiScriptName, reverse ? "" : "r", et->id, string_rawstr(query_string_a));
         h(et->name);
         o("</a>\n");
         o("\t\t</th>\n");
     }
-    o("\t\t<th class=\"registerdate\"><a href=\"%s/search?%ssort=-2&amp;%s#result\" title=\"押す度に昇順、降順で並べ替えを行ないます。\">投稿日時</a></th>\n", cgiScriptName, reverse ? "" : "r", query_string);
-    o("\t\t<th class=\"lastregisterdate\"><a href=\"%s/search?%ssort=-3&amp;%s#result\" title=\"押す度に昇順、降順で並べ替えを行ないます。\">最終更新日時</a></th>\n", cgiScriptName, reverse ? "" : "r", query_string);
-    o("\t\t<th class=\"leftdate\"><a href=\"%s/search?%ssort=-3&amp;%s#result\" title=\"押す度に昇順、降順で並べ替えを行ないます。\">放置日数</a></th>\n", cgiScriptName, reverse ? "" : "r", query_string);
+    o("\t\t<th class=\"registerdate\"><a href=\"%s/search?%ssort=-2&amp;%s#result\" title=\"押す度に昇順、降順で並べ替えを行ないます。\">投稿日時</a></th>\n", cgiScriptName, reverse ? "" : "r", string_rawstr(query_string_a));
+    o("\t\t<th class=\"lastregisterdate\"><a href=\"%s/search?%ssort=-3&amp;%s#result\" title=\"押す度に昇順、降順で並べ替えを行ないます。\">最終更新日時</a></th>\n", cgiScriptName, reverse ? "" : "r", string_rawstr(query_string_a));
+    o("\t\t<th class=\"leftdate\"><a href=\"%s/search?%ssort=-3&amp;%s#result\" title=\"押す度に昇順、降順で並べ替えを行ないます。\">放置日数</a></th>\n", cgiScriptName, reverse ? "" : "r", string_rawstr(query_string_a));
     o("\t</tr>\n");
+    string_free(query_string_a);
 }
 void output_ticket_table_body(SearchResult* result, List* element_types)
 {
@@ -362,7 +362,7 @@ void list_action()
     list_free(states_a);
     o("\t\t<li>\n");
     o("\t\t\t<form action=\"%s/search\" method=\"get\">\n", cgiScriptName);
-    o("\t\t\t\t<input type=\"text\" class=\"number\" name=\"id\" title=\"入力したIDのチケットを表示します。\" />\n"
+    o("\t\t\t\t<input type=\"text\" class=\"number\" name=\"id\" title=\"入力したIDのチケットを表示します。\" maxlength=\"1000\" />\n"
       "\t\t\t\t<input type=\"submit\" class=\"button\" value=\"ID指定で表示\" />\n"
       "\t\t\t</form>\n"
       "\t\t</li>\n"
@@ -592,7 +592,7 @@ void search_actoin()
     list_free(states_a);
     o("\t\t<li>\n");
     o("\t\t\t<form action=\"%s/search\" method=\"get\">\n", cgiScriptName);
-    o("\t\t\t\t<input type=\"text\" class=\"number\" name=\"id\" title=\"入力したIDのチケットを表示します。\" />\n"
+    o("\t\t\t\t<input type=\"text\" class=\"number\" name=\"id\" title=\"入力したIDのチケットを表示します。\" maxlength=\"1000\" />\n"
       "\t\t\t\t<input type=\"submit\" class=\"button\" value=\"ID指定で表示\" />\n"
       "\t\t\t</form>\n"
       "\t\t</li>\n"
@@ -618,6 +618,14 @@ void search_actoin()
         o("\t<td>\n"); 
         output_form_element_4_condition(et);
         o("\t</td>\n");
+        if (!iterator_next(it)) {
+            /* 空いたセルの調整 */
+            int i = col_index;
+            for (; i < 3; i++) {
+                o("\t<th>&nbsp;</th>\n");
+                o("\t<td>&nbsp;</td>\n");
+            }
+        }
         if (col_index == 3 || !iterator_next(it))
             o("</tr>\n");
         col_index = col_index++ == 3 ? 1 : col_index;
@@ -629,21 +637,29 @@ void search_actoin()
     o("<tr>\n"
       "\t<th>キーワード検索</th>\n"
       "\t<td>\n"
-      "\t\t<input type=\"text\" class=\"conditionelement\" name=\"q\" value=\""); v(q); o("\" />\n"
+      "\t\t<input type=\"text\" class=\"conditionelement\" name=\"q\" value=\""); v(q); o("\" maxlength=\"1000\" />\n"
       "\t\t<div class=\"description\">履歴も含めて全ての項目から検索を行ないます。</div>\n"
       "\t</td>\n"
       "\t<th>投稿日時</th>\n"
       "\t<td>\n"
-      "\t\t<input type=\"text\" class=\"calendar\" name=\"registerdate.from\" value=\""); v(registerdate_from); o("\" />\n"
+      "\t\t<span>\n"
+      "\t\t<input type=\"text\" class=\"calendar\" name=\"registerdate.from\" value=\""); v(registerdate_from); o("\" maxlength=\"20\" />\n"
+      "\t\t</span>\n"
       "〜\n"
-      "\t\t<input type=\"text\" class=\"calendar\" name=\"registerdate.to\" value=\""); v(registerdate_to); o("\" />\n"
+      "\t\t<span>\n"
+      "\t\t<input type=\"text\" class=\"calendar\" name=\"registerdate.to\" value=\""); v(registerdate_to); o("\" maxlength=\"20\" />\n"
+      "\t\t</span>\n"
       "\t\t<div class=\"description\">yyyy-mm-dd形式で入力してください。</div>\n"
       "\t</td>\n"
       "\t<th>更新日時</th>\n"
       "\t<td>\n"
-      "\t\t<input type=\"text\" class=\"calendar\" name=\"lastregisterdate.from\" value=\""); v(updatedate_from); o("\" />\n"
+      "\t\t<span>\n"
+      "\t\t<input type=\"text\" class=\"calendar\" name=\"lastregisterdate.from\" value=\""); v(updatedate_from); o("\" maxlength=\"20\" />\n"
+      "\t\t</span>\n"
       "〜\n"
-      "\t\t<input type=\"text\" class=\"calendar\" name=\"lastregisterdate.to\" value=\""); v(updatedate_to); o("\" />\n"
+      "\t\t<span>\n"
+      "\t\t<input type=\"text\" class=\"calendar\" name=\"lastregisterdate.to\" value=\""); v(updatedate_to); o("\" maxlength=\"20\" />\n"
+      "\t\t</span>\n"
       "\t\t<div class=\"description\">yyyy-mm-dd形式で入力してください。</div>\n"
       "\t</td>\n"
       "</tr>\n"
@@ -657,19 +673,19 @@ void search_actoin()
       "<h3>検索結果</h3>\n");
 
     if (result_a->messages->size) {
-        char query_string_buffer[DEFAULT_LENGTH];
-        char* query_string;
+        String* query_string_a = string_new(0);
 
-        query_string = format_query_string_without_page(query_string_buffer);
+        query_string_a = format_query_string_without_page(query_string_a);
         o(      "<div class=\"infomation\">");
         o(      "%d件ヒットしました。\n", result_a->hit_count);
         o(      "<a href=\"%s/report_csv_download?%s\" target=\"_blank\">検索結果をCSVでダウンロードする。</a>\n",
                 cgiScriptName,
-                query_string);
+                string_rawstr(query_string_a));
         o(      "</div>\n");
-        output_navigater(result_a, query_string);
+        output_navigater(result_a, string_rawstr(query_string_a));
         output_ticket_table(result_a, element_types_a);
-        output_navigater(result_a, query_string);
+        output_navigater(result_a, string_rawstr(query_string_a));
+        string_free(query_string_a);
     }
     o("</div>\n");
     output_footer();
@@ -815,6 +831,7 @@ void output_form_element_4_condition(ElementType* et)
         case ELEM_TYPE_DATE:
             sprintf(name, "field%d_from", et->id);
             cgiFormStringNoNewlines(name, value, DEFAULT_LENGTH);
+            o("<span>\n");
             o("<input type=\"text\" class=\"calendar\" id=\"field");
             h(id);
             o("\" name=\"field");
@@ -822,9 +839,11 @@ void output_form_element_4_condition(ElementType* et)
             o("_from\" value=\"");
             v(value);
             o("\" maxlength=\"10\" />\n");
+            o("</span>\n");
             o("〜\n");
             sprintf(name, "field%d_to", et->id);
             cgiFormStringNoNewlines(name, value, DEFAULT_LENGTH);
+            o("<span>\n");
             o("<input type=\"text\" class=\"calendar\" id=\"field");
             h(id);
             o("\" name=\"field");
@@ -832,6 +851,7 @@ void output_form_element_4_condition(ElementType* et)
             o("_to\" value=\"");
             v(value);
             o("\" maxlength=\"10\" />\n");
+            o("</span>\n");
             break;
     }
 }
@@ -869,7 +889,7 @@ void output_form_element(List* elements, ElementType* et)
             o("<input type=\"text\" class=\"element\" id=\"field%d\" name=\"field%d\" value=\"",
                     et->id, et->id);
             v(value);
-            o("\" />\n");
+            o("\" maxlength=\"1000\" />\n");
             break;
         case ELEM_TYPE_TEXTAREA:
             o("<textarea id=\"field%d\" name=\"field%d\" rows=\"3\" cols=\"10\">",
@@ -936,10 +956,12 @@ void output_form_element(List* elements, ElementType* et)
             o("<div class=\"description\">ファイルサイズは、%dKb以下になるようにしてください。</div>\n", MAX_FILE_SIZE);
             break;
         case ELEM_TYPE_DATE:
+            o("<span>\n");
             o("<input type=\"text\" class=\"calendar\" id=\"field%d\" name=\"field%d\" value=\"\n",
                     et->id, et->id);
             v(value);
             o("\" maxlength=\"10\"/>\n"
+              "</span>\n"
               "<div class=\"description\">yyyy-mm-dd形式で入力してください。</div>\n");
             break;
     }
@@ -948,7 +970,7 @@ void output_form_element(List* elements, ElementType* et)
         case ELEM_TYPE_LIST_MULTI:
             if (et->auto_add_item) {
                 /* 新規項目を設定可能である場合、テキストボックスを表示する。 */
-                o("<input type=\"text\" class=\"element_new_item\" id=\"field%d.new_item\" name=\"field%d.new_item\" />\n",
+                o("<input type=\"text\" class=\"element_new_item\" id=\"field%d.new_item\" name=\"field%d.new_item\" maxlength=\"1000\" />\n",
                     et->id, et->id);
                 o("選択肢を追加する場合はテキストボックスに入力してください。\n");
             }
@@ -1051,6 +1073,12 @@ void register_action()
             "<label for=\"save2cookie\">投稿者を保存する。(cookie使用)</label>\n"
             "</form>\n"
             "</div>\n", strlen(sender) ? "checked" : "");
+    o(      "<div class=\"description\">\n"
+            "\t<ul>\n"
+            "\t\t<li>複数行テキスト項目の内容では、#1 のように書くと、ID が 1 のチケットのチケット詳細ページへのリンクとなります。</li>\n"
+            "\t\t<li>複数行テキスト項目の内容では、行頭が >| から始まる行から、行頭が |< から始まる行までは、整形済みブロックになります。</li>\n"
+            "\t</ul>\n"
+            "</div>\n");
     db_finish();
     output_footer();
 }
@@ -1242,13 +1270,9 @@ void ticket_action()
         if (et->ticket_property == 0) continue;
         o("\t<tr>\n");
         o("\t\t<th %s>", et->required ? "class=\"required\"" : "");
-        if (et->ticket_property)
-            o("&nbsp;<span class=\"ticket_property\" title=\"チケット属性\">");
         h(et->name);
         if (et->required)
             o("<span class=\"required\">※</span>");
-        if (et->ticket_property)
-            o("</span>");
         o("</th>\n\t\t<td>");
         if (et->required)
             o("\t\t<div id=\"field%d.required\" class=\"error\"></div>\n", et->id);
@@ -1259,7 +1283,6 @@ void ticket_action()
                 output_form_element(last_elements, et);
             else
                 output_form_element(NULL, et);
-/*                 last_elements = last_elements->next; */
         } else {
             output_form_element(NULL, et);
         }
@@ -1293,7 +1316,6 @@ void ticket_action()
                 output_form_element(last_elements, et);
             else
                 output_form_element(NULL, et);
-/*                 last_elements = last_elements->next; */
         } else {
             output_form_element(NULL, et);
         }
@@ -1307,6 +1329,12 @@ void ticket_action()
             "<label for=\"save2cookie\">投稿者を保存する。(cookie使用)</label>\n"
             "</form>\n"
             "</div>\n", strlen(sender) ? "checked" : "");
+    o(      "<div class=\"description\">\n"
+            "\t<ul>\n"
+            "\t\t<li>複数行テキスト項目の内容では、#1 のように書くと、ID が 1 のチケットのチケット詳細ページへのリンクとなります。</li>\n"
+            "\t\t<li>複数行テキスト項目の内容では、行頭が >| から始まる行から、行頭が |< から始まる行までは、整形済みブロックになります。</li>\n"
+            "\t</ul>\n"
+            "</div>\n");
     output_field_information_js(element_types_a);
     db_finish();
     output_footer();
@@ -1545,7 +1573,7 @@ void top_action()
     o(      "<div id=\"top_id_search\">\n"
             "<h4>ID検索</h4>\n"
             "\t<form action=\"%s/search\" method=\"get\">\n", cgiScriptName);
-    o(      "\t\t<input type=\"text\" class=\"number\" name=\"id\" title=\"入力したIDのチケットを表示します。\" />\n"
+    o(      "\t\t<input type=\"text\" class=\"number\" name=\"id\" title=\"入力したIDのチケットを表示します。\" maxlength=\"1000\" />\n"
             "\t\t<input type=\"submit\" class=\"button\" value=\"表示\" />\n"
             "\t</form>\n"
             "</div>\n"
@@ -1776,12 +1804,13 @@ void edit_top_action()
 }
 void edit_top_submit_action()
 {
-    char value[VALUE_LENGTH];
+    char* value_a = xalloc(sizeof(char) * VALUE_LENGTH);
 
-    cgiFormString("edit_top", value, VALUE_LENGTH);
+    cgiFormString("edit_top", value_a, VALUE_LENGTH);
     db_init();
-    wiki_save("top", value);
+    wiki_save("top", value_a);
     db_finish();
+    xfree(value_a);
 
     redirect("", NULL);
 }
